@@ -11,16 +11,20 @@
 #' @return the output will be a character vector with p values, e.g.,
 #' a vector of strings like "< .001" (or "p < .001").
 #' @examples
-#' pretty_round_p_value(0.0495, 3)
+#' pretty_round_p_value(0.00001)
+#' pretty_round_p_value(0.00001, round_digits_after_decimal = 4)
+#' pretty_round_p_value(0.00001, round_digits_after_decimal = 5)
+#' # WARNING: the line of code below adding precision that may be unwarranted
+#' pretty_round_p_value(0.00001, round_digits_after_decimal = 6)
 #' pretty_round_p_value(
 #'   p_value_vector = 0.049,
 #'   round_digits_after_decimal = 2, include_p_equals = FALSE)
 #' pretty_round_p_value(c(0.0015, 0.0014, 0.0009), include_p_equals = TRUE)
 #' @export
 pretty_round_p_value <- function(
-  p_value_vector = NULL,
-  round_digits_after_decimal = 3,
-  include_p_equals = FALSE) {
+    p_value_vector = NULL,
+    round_digits_after_decimal = 3,
+    include_p_equals = FALSE) {
   # check if numeric
   if (is.numeric(p_value_vector) == FALSE) {
     stop(paste0("The input for p_value_vector is not a numeric vector."))
@@ -28,7 +32,7 @@ pretty_round_p_value <- function(
   # check if negative values exist
   if (any(p_value_vector[!is.na(p_value_vector)] < 0)) {
     stop(paste0("The input for p_value_vector contains a negative ",
-    "p-value, which should not possible."))
+                "p-value, which should not possible."))
   }
   # check if p-values are between 0 and 1
   if (any(p_value_vector[!is.na(p_value_vector)] > 1)) {
@@ -40,7 +44,11 @@ pretty_round_p_value <- function(
     # include the p and equal sign
     if (include_p_equals == TRUE) {
       output <- ifelse(
-        p_value_vector < .001, "p < .001",
+        p_value_vector < 1 / (10 ^ round_digits_after_decimal),
+        paste0("p < ", gsub(
+          "^0\\.", ".",
+          as.character(format(
+            1 / (10 ^ round_digits_after_decimal), scientific = FALSE)))),
         paste0("p = ", sub("^0?", "", sprintf(
           paste0("%.", round_digits_after_decimal, "f"),
           p_value_vector))))
@@ -48,7 +56,11 @@ pretty_round_p_value <- function(
     }
     # exclude the p and equal sign
     output <- ifelse(
-      p_value_vector < .001, "< .001",
+      p_value_vector < 1 / (10 ^ round_digits_after_decimal),
+      paste0("< ", gsub(
+        "^0\\.", ".",
+        as.character(format(
+          1 / (10 ^ round_digits_after_decimal), scientific = FALSE)))),
       sub("^0?", "", sprintf(
         paste0("%.", round_digits_after_decimal, "f"),
         p_value_vector)))
